@@ -1,11 +1,19 @@
 from .logger import Logger
 from .filehandler import FileHandler
 from .consolehandler import ConsoleHandler
+from .jsonhandler import JSONHandler
 
+from .handler import Handler
 from .log_levels import LogLevel
 
-__version__ = "1.0.0"
-__all__ = ["Logger", "FileHandler", "ConsoleHandler", "LogLevel"]
+
+__version__ = "1.1.2"
+__all__ = ["Logger",
+           "Handler",
+           "FileHandler",
+           "ConsoleHandler",
+           "JSONHandler",
+           "LogLevel"]
 
 __author__ = "mrmajor.programmer"
 __author_email__ = "mrmajork.programmer@gmail.com"
@@ -23,14 +31,14 @@ PyPi: https://pypi.org/project/loggingpython
 GitHub: https://github.com/loggingpython-Community/loggingpython""")
 
 
-def getLogger() -> Logger:
+def getLogger(name: str = "Root-Logger") -> Logger:
     """
         Creates and returns an instance of the logger.
 
         Returns:
             Logger: An instance of the logger.
         """
-    return Logger()
+    return Logger(name)
 
 
 def getBasicLogger() -> Logger:
@@ -47,5 +55,12 @@ def getBasicLogger() -> Logger:
     return logger
 
 
+def get_all_handlers() -> None:
+    """
+    Returns a list of all available handler classes.
+    """
+    print("'FileHandler','ConsoleHandler','JSONHandler'")
+
+
 if __name__ != '__main__':
     hello_from_loggingpython()
